searchData={"items":[{"type":"module","title":"LivePalette","doc":"`LivePalette` is a component for `Phoenix.LiveView` that allows the user to implement a command palette,\nreminiscent of the VSCode and Sublime Command Palettes, the macOS Spotlight and Alfred, and Linear's Command-K Command Bar.","ref":"LivePalette.html"},{"type":"function","title":"LivePalette.live_palette/1","doc":"The live palette component itself.","ref":"LivePalette.html#live_palette/1"},{"type":"function","title":"Attributes - LivePalette.live_palette/1","doc":"* `id` (`:string`) (required) - The component ID. The underlying implementation of the LivePalette component is a LiveComponent, which requires a component ID.\n* `actions` (`:list`) (required) - The list of possible actions available to this palette.\n  Actions passed in to this list must implement the `LivePalette.Actionable` protocol.\n\n* `show_on_initial_render` (`:boolean`) - Whether or not to show the palette on the initial render. The LivePalette is a LiveComponent,\n  so this property once set is then owned by the component itself, meaning that it should only be set once (on render),\n  and subsequently left to the component to decide when to show or hide.\n  This is by default set to false, however, in cases such as a reconnect or a refresh,\n  when one might want to ensure that the user receives the same view that they had previously,\n  this can be set to true to show it on the initial render.\n\n  Defaults to `false`.\n* `key` (`:string`) - The key that should trigger showing the palette. This defaults to K. Defaults to `\"K\"`.\n* `require_metakey` (`:boolean`) - Whether or not the key should be pressed with the meta key. An explanation of how to enable the metadata that includes\n  whether the meta key was pressed can be found on the [Phoenix LiveView Key Events documentation](https://hexdocs.pm/phoenix_live_view/bindings.html#key-events).\n  If set to true, this will expect that you have enabled this metadata on your socket, and it will only match and toggle\n  the palette when both the given key and the meta key are pressed together.\n\n  Defaults to `false`.\n* `match_threshold` (`:float`) - The minimum threshold that we need in order to determine if the action is a match to a specific search term.\n  The action's title and subtitle will be checked against the search term as the user types it, and the actions\n  will be sorted by score.\n\n  The value must be a float between 0.0 and 1.0.\n  The default threshold to 0.3.\n\n  Defaults to `0.3`.\n* `maximum_results` (`:integer`) - The maximum results to show when displaying the results of actions in the list.\n  The default maximum is 10.\n\n  Defaults to `10`.\n* `metakey_param` (`:string`) - The param on the key event that the meta key value appears in. When setting `require_metakey` to `true`,\n  this value is used to get the parameter from the params sent in the event. By default, this is set to `\"metaKey\"`,\n  which is taken from the example provided in the [Phoenix LiveView Key Events documentation](https://hexdocs.pm/phoenix_live_view/bindings.html#key-events).\n\n  If you have a different parameter name, you must update this attribute in order to ensure that it is properly matched.\n\n  Defaults to `\"metaKey\"`.\n* `placeholder` (`:string`) - The placeholder that will be added to the palette's input.\n  This defaults to \"Enter your command\".\n\n  Defaults to `\"Enter your command\"`.\n* `show_all_results_on_empty_input` (`:boolean`) - Whether or not to show all of the results when the input is empty.\n  This is set to false by default, however, when set to true, when the input is empty\n  we will create a full list of all of the palettes actions and show them in a scrollable list.\n\n  It is recommended to leave this set to false if the amount of actions is large, as this can cause\n  very large diffs to be sent to the client. However, if the number of actions in the palette is relatively\n  short, this can be set to true to show the user all available actions.\n\n  Defaults to `false`.\n* `icon_component` (`:any`) - The icon component is the functional component that is used to render icons in the Palette's results list.\n  It defaults to the icon component that is generated by Phoenix's app generator, which is based on Heroicons\n  and your tailwind.config.js embedding the Heroicons properly in CSS.\n\n  However, it can be overridden to be any icon component that you would like to use.\n\n  The icon component must conform to the same contract as the default icon component -\n  it will receive a `:name` as a string and a `:class` as a string in its assigns\n  and that's it, in order to maintain compatibility with the default component.\n\n  Defaults to `&LivePalette.Icon.icon/1`.","ref":"LivePalette.html#live_palette/1-attributes"},{"type":"module","title":"LivePalette.Action","doc":"`LivePalette.Action` defines the action struct that is used internally in `LivePalette`.\nIt contains details that allow us to render the action in the results list.","ref":"LivePalette.Action.html"},{"type":"type","title":"LivePalette.Action.t/0","doc":"`LivePalette.Action` contains multiple fields that can be used to determine how to render an action in the `LivePalette`.\n\n`:title` and `:always_show?` are required when creating a `LivePalette.Action` - they determine what the action is called,\nand whether is is statically shown in all results all the time. Results that match will be shown before those that are defined\nwith `:always_show?` set to `true`.","ref":"LivePalette.Action.html#t:t/0"},{"type":"protocol","title":"LivePalette.Actionable","doc":"","ref":"LivePalette.Actionable.html"},{"type":"function","title":"LivePalette.Actionable.to_action/1","doc":"","ref":"LivePalette.Actionable.html#to_action/1"},{"type":"type","title":"LivePalette.Actionable.t/0","doc":"All the types that implement this protocol.","ref":"LivePalette.Actionable.html#t:t/0"},{"type":"protocol","title":"LivePalette.Actionable.ExternallyLinkable","doc":"","ref":"LivePalette.Actionable.ExternallyLinkable.html"},{"type":"function","title":"LivePalette.Actionable.ExternallyLinkable.link_external/1","doc":"","ref":"LivePalette.Actionable.ExternallyLinkable.html#link_external/1"},{"type":"type","title":"LivePalette.Actionable.ExternallyLinkable.t/0","doc":"All the types that implement this protocol.","ref":"LivePalette.Actionable.ExternallyLinkable.html#t:t/0"},{"type":"protocol","title":"LivePalette.Actionable.Linkable","doc":"","ref":"LivePalette.Actionable.Linkable.html"},{"type":"function","title":"LivePalette.Actionable.Linkable.link_to/1","doc":"","ref":"LivePalette.Actionable.Linkable.html#link_to/1"},{"type":"type","title":"LivePalette.Actionable.Linkable.t/0","doc":"All the types that implement this protocol.","ref":"LivePalette.Actionable.Linkable.html#t:t/0"},{"type":"protocol","title":"LivePalette.Actionable.Renderable","doc":"","ref":"LivePalette.Actionable.Renderable.html"},{"type":"function","title":"LivePalette.Actionable.Renderable.render/2","doc":"","ref":"LivePalette.Actionable.Renderable.html#render/2"},{"type":"type","title":"LivePalette.Actionable.Renderable.t/0","doc":"All the types that implement this protocol.","ref":"LivePalette.Actionable.Renderable.html#t:t/0"},{"type":"module","title":"LivePalette.Icon","doc":"`LivePalette.Icon` is the default icon component used to render icons in the LivePalette results.\nIt is a copy of the generated CoreComponent for icon that is added in Phoenix's project generation.","ref":"LivePalette.Icon.html"},{"type":"function","title":"LivePalette.Icon.icon/1","doc":"Renders a [Heroicon](https://heroicons.com).\n\nHeroicons come in three styles – outline, solid, and mini.\nBy default, the outline style is used, but solid and mini may\nbe applied by using the `-solid` and `-mini` suffix.\n\nYou can customize the size and colors of the icons by setting\nwidth, height, and background color classes.\n\nIcons are extracted from the `deps/heroicons` directory and bundled within\nyour compiled app.css by the plugin in your `assets/tailwind.config.js`.","ref":"LivePalette.Icon.html#icon/1"},{"type":"function","title":"Examples - LivePalette.Icon.icon/1","doc":"<.icon name=\"hero-x-mark-solid\" />\n    <.icon name=\"hero-arrow-path\" class=\"ml-1 w-3 h-3 animate-spin\" />","ref":"LivePalette.Icon.html#icon/1-examples"},{"type":"function","title":"Attributes - LivePalette.Icon.icon/1","doc":"* `name` (`:string`) (required)\n* `class` (`:string`) - Defaults to `nil`.","ref":"LivePalette.Icon.html#icon/1-attributes"},{"type":"exception","title":"LivePalette.Actionable.NotImplemented","doc":"","ref":"LivePalette.Actionable.NotImplemented.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added new features","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed an existing functionality","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecated a feature so that it can be removed in a later release","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed a feature","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bugfix","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- Patched a security vulnerability\n\n[Unreleased]: https://github.com/probably-not/live-palette/compare/v0.1.0...HEAD\n[0.1.0]: https://github.com/probably-not/live-palette/releases/tag/v0.1.0","ref":"changelog.html#security"},{"type":"extras","title":"README","doc":"# LivePalette\n\n[![Hex.pm Version](https://img.shields.io/hexpm/v/live_palette.svg)](https://hex.pm/packages/live_palette) [![Documentation](https://img.shields.io/badge/docs-latest-blue.svg)](https://hexdocs.pm/live_palette/)\n\nA command palette for LiveView.\nReminiscent of the VSCode and Sublime Command Palettes, the macOS Spotlight and Alfred, and Linear's Command-K Command Bar.","ref":"readme.html"},{"type":"extras","title":"Usage - README","doc":"Start by installing the `live_palette` package from Hex.\n\n```elixir\ndef deps do\n  [\n    {:live_palette, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}